about summary refs log tree commit diff
path: root/bits
diff options
context:
space:
mode:
Diffstat (limited to 'bits')
-rw-r--r--bits/sigthread.h21
1 files changed, 16 insertions, 5 deletions
diff --git a/bits/sigthread.h b/bits/sigthread.h
index de6f2dc73e..6e23a2c5e3 100644
--- a/bits/sigthread.h
+++ b/bits/sigthread.h
@@ -1,5 +1,5 @@
-/* Signal handling function for threaded programs.
-   Copyright (C) 1998 Free Software Foundation, Inc.
+/* Signal handling function for threaded programs.  Generic version.
+   Copyright (C) 2000 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -17,8 +17,19 @@
    write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.  */
 
-#ifndef _SIGNAL_H
-# error "Never include this file directly.  Use <signal.h> instead"
+#ifndef _BITS_SIGTHREAD_H
+#define _BITS_SIGTHREAD_H	1
+
+#if !defined _SIGNAL_H && !defined _PTHREAD_H
+# error "Never include this file directly.  Use <pthread.h> instead"
 #endif
 
-/* There are none available in this configuration.  */
+/* Modify the signal mask for the calling thread.  The arguments have the
+   same meaning as for sigprocmask; in fact, this and sigprocmask might be
+   the same function.  We declare this the same on all platforms, since it
+   doesn't use any thread-related types.  */
+extern int pthread_sigmask (int __how, __const __sigset_t *__newmask,
+			    __sigset_t *__oldmask) __THROW;
+
+
+#endif	/* bits/sigthread.h */